<?php
/*
Plugin Name: Twitter Hashtag-based Conversation
Plugin URI: http://pixeline.be
Description: Displays the most recent twitter status updates for a particular hash tag in your posts/pages using shortcode: [twitter_hashtag hash="YOUR_TAG" number="NUMBER_OF_TWEETS_TO_GET" ].
Version: 1.6.2
Author: pixeline
Author URI: http://www.pixeline.be
*/
/*	Copyright 2012	pixeline  (email : alexandre@pixeline.be)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License, version 2, as
	published by the Free Software Foundation.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

if (!class_exists('TwitterHashtagConversation')) {
	class TwitterHashtagConversation {
		protected $pluginPath;
		protected $pluginUrl;
		protected $twitterApiUrl;
		protected $pluginVersion;
		protected $pluginId;

		var $options = array();

		var $optionsName = 'pixeline_hashtag_conversation_options';
		var $localizationDomain = 'twitter-hashtag-conversation';


		// PHP4-compatibility
		function TwitterHashtagConversation(){$this->__construct();}

		public function __construct()
		{

			//Language Setup
			$locale = get_locale();
			$mo=	 plugin_dir_path(__FILE__).'languages/'.$this->localizationDomain . "-".$locale.".mo";
			load_textdomain($this->localizationDomain, $mo);

			// constants setup
			$this->pluginId = 'twitter-hashtag-conversation';
			$this->pluginVersion = '1.5';
			$this->pluginPath   =  dirname(__FILE__);
			$this->pluginUrl	  =	 WP_PLUGIN_URL . '/'.basename($this->pluginPath);
			$this->twitterApiUrl	 =	'http://search.twitter.com/search?q=';

			$this->getOptions();

			//Admin menu
			add_action("admin_menu", array(&$this,"admin_menu_link"));

			add_shortcode('twitter_hashtag', array($this, 'shortcode'));
			add_filter('the_posts', array(&$this,'scripts_and_styles'));
			
			// Add shortcode support for widgets
			 add_filter('widget_text', 'do_shortcode');	

			// END CONSTRUCT
		}


		/**
		 * @desc Adds the options subpanel
		 */
		function admin_menu_link() {

			add_options_page('Twitter Hashtag Conversation', 'Twitter Hashtag Conversation', 10, basename(__FILE__), array(&$this,'admin_options_page'));
			add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), array(&$this, 'filter_plugin_actions'), 10, 2 );
		}

		/**
		 * @desc Adds the Settings link to the plugin activate/deactivate page
		 */
		function filter_plugin_actions($links, $file) {
			$settings_link = '<a href="options-general.php?page=' . basename(__FILE__) . '">' . __('Settings') . '</a>';
			array_unshift( $links, $settings_link ); // before other links

			return $links;
		}

		// ADD JS and CSS IN FRONTEND WHEN RELEVANT

		function scripts_and_styles($posts){
			if (empty($posts)) return $posts;
			$shortcode_found = false;

			foreach ($posts as $post) {
				if (stripos($post->post_content, '[twitter_hashtag') !== false) {
					$shortcode_found = true; // bingo!
					break;
				}
			}

			if ($shortcode_found) {
				// enqueue here
				if(!is_admin()){
					$pth_plugin_url = plugin_dir_url(__FILE__);
					wp_enqueue_script('jquery');
					wp_enqueue_script('pixeline_hashtag_conversation', $this->pluginUrl.'/'.$this->pluginId.'.js', array('jquery'));
					wp_enqueue_style('pixeline_hashtag_conversation', $this->pluginUrl.'/'.$this->pluginId.'.css');

				}
			}

			return $posts;
		}

		/**
		 * @desc Retrieves the plugin options from the database.
		 * @return array
		 */
		function getOptions() {
			if (!$theOptions = get_option($this->optionsName)) {
				$theOptions = array(

					'default_tag'=> 'Wordpress',
					'default_number' => '5',
					'loading_str'=>'Please wait, fetching the tweets…',
					'update_str'=>'Refreshing…',
					'refresh_rate'=>'60',
					'title'=>'The twitter conversation on <em>{HASH_LINK}</em>',
					'right_now'=>'Right now',
					'onemin_ago'=>'1 minute ago',
					'xmin_ago'=>'{TIME} minutes ago',
					'onehour_ago'=>'1 hour ago',
					'xhours_ago'=>'1 hour ago',
					'yesterday'=> 'Yesterday',
					'xdays_ago'=> '{TIME} days ago',
					'xweeks_ago'=> '{TIME} weeks ago');

				update_option($this->optionsName, $theOptions);
			}

			foreach ($theOptions as $k=>$v){
				$theOptions[$k]= stripslashes($v);
			}

			$this->options = $theOptions;
		}
		/**
		 * Saves the admin options to the database.
		 */
		function saveAdminOptions(){
			return update_option($this->optionsName, $this->options);
		}


		function admin_options_page() {
			if($_POST['plugin_save' ]){
				if (! wp_verify_nonce($_POST['_wpnonce'], 'pxlntwttrhshtg_update-options') ) die('Whoops! There was a problem with the data you posted. Please go back and try again.');

				$this->options['default_tag'] =$_POST['default_tag'];
				$this->options['default_number'] =	(int)$_POST['default_number'];
				$this->options['loading_str'] = $_POST['loading_str'];
				$this->options['update_str'] = $_POST['update_str'];
				$this->options['title'] = $_POST['title'];
				$this->options['refresh_rate'] = ($_POST['refresh_rate']<24) ? 24 : (int)$_POST['refresh_rate'] ;
				$this->options['right_now'] = $_POST['right_now'];
				$this->options['onemin_ago'] = $_POST['onemin_ago'];
				$this->options['xmin_ago'] = $_POST['xmin_ago'];
				$this->options['onehour_ago'] = $_POST['onehour_ago'];
				$this->options['xhours_ago'] = $_POST['xhours_ago'];
				$this->options['yesterday'] = $_POST['yesterday'];
				$this->options['xdays_ago'] = $_POST['xdays_ago'];
				$this->options['xweeks_ago'] = $_POST['xweeks_ago'];

				$this->saveAdminOptions();

				echo '<div class="updated"><p>Success! Your changes were sucessfully saved!</p></div>';

			}
?>

			<h2>Twitter Hashtag Conversation</h2>
			<p>
			<?php _e('by <a href="http://www.pixeline.be" target="_blank" class="external">pixeline</a>', $this->localizationDomain); ?>
			</p>
<h3>Usage</h3>
<p>Use the following shortcode inside your blog posts, exactly where you wish to display the twitter stream:<br><br><code>[twitter_hashtag hash="YOUR_TAG_WITHOUT_THE_#_SIGN" number="NUMBER_OF_TWEETS_TO_GET" title="TITLE TO DISPLAY"]</code></p>
<p><b>Example:</b> <code>[twitter_hashtag hash="design" number="10" title="Latest tweets about {HASH_LINK}"]</code></p>

<p><h4>Notes:</h4> 
<ol>
<li>You may use several keywords if you want, just separate each with a comma <kbd>,</kbd>. It will return all tweets with either or both keywords.<br><br>Example: <code>[twitter_hashtag hash="design,development" number="10" title="Latest tweets about {HASH_LINK}"]</code></li>
</ol>
<hr>
<h3>Options</h3>
			<form method="post" id="pxlntwttrhshtg_plugin_options">
			<?php wp_nonce_field('pxlntwttrhshtg_update-options'); ?>
				<table width="100%" cellspacing="2" cellpadding="5" class="form-table">
				<tbody>
				<tr>
					<th scope="row"><label for="default_tag"><?php _e('Default hashtag to search', $this->localizationDomain) ?></label></th>
					<td><input type="text" name="default_tag" value="<?php echo $this->options['default_tag']; ?>" id="default_tag" /></td>
				</tr>

				<tr>
					<th scope="row"><label for="pth_default_title"><?php _e('Default title', $this->localizationDomain) ?></label></th>
					<td><input type="text" name="title" value="<?php echo stripslashes($this->options['title']); ?>" id="pth_default_title" size="100" />
					<br><span class="setting-description">
					<?php _e('You can use <code title="Displays the keyword/hashtag">{HASH}</code>, <code title="Shows a link to the keyword\'s search results on twitter.com">{HASH_LINK}</code> and <code title="Shows the number of tweets displayed">{NUMBER}</code> in the title and they will be replaced by their value.', $this->localizationDomain);?></pan></td>
				</tr>

				<tr>
					<th scope="row"><label for="pth_default_number"><?php _e('Default number of tweets to fetch', $this->localizationDomain) ?></label></th>
					<td><input type="text" name="default_number" value="<?php echo stripslashes($this->options['default_number']); ?>" id="pth_default_number" size="2" /></td>
				</tr>

				<tr>
					<th scope="row"><label for="pth_loading_str"><?php _e('Initial loading message:', $this->localizationDomain) ?></label></th>
					<td><input type="text" name="loading_str" value="<?php echo stripslashes($this->options['loading_str']); ?>" id="pth_loading_str" size="100" /></td>
				</tr>
				<tr>
					<th scope="row"><label for="pth_update_str"><?php _e('Message: "updating the conversation" ', $this->localizationDomain) ?></label></th>
					<td><input type="text" name="update_str" value="<?php echo stripslashes($this->options['update_str']); ?>" id="pth_update_str" /></td>
				</tr>

				<tr>
					<th scope="row"><label for="pth_refresh_rate"><?php _e('Number of seconds between each refresh ', $this->localizationDomain) ?></label></th>
					<td><input type="text" name="refresh_rate" value="<?php echo stripslashes($this->options['refresh_rate']); ?>" id="pth_refresh_rate" />
					<br><span class="setting-description"><?php _e('Cannot be below 24 , see <a href="https://dev.twitter.com/docs/rate-limiting">Twitter Documentation</a>', $this->localizationDomain) ?></span>
					</td>
				</tr>

				<tr>
					<th scope="row"><label><?php _e('Pretty date', $this->localizationDomain) ?></label></th>
					<td>
						<p><?php _e('The plugin displays user-relative time instead of objective date and time (e.g: "One minute ago"). You can specify here how it should be translated in your language.', $this->localizationDomain) ?></p>
						<fieldset>
						<legend><?php _e('Pretty date', $this->localizationDomain); ?></legend>
						<p>
	<label for="pretty_time_right_now"><?php _e("Now", $this->localizationDomain);?></label><br>
	<input type="text" name="right_now" value="<?php echo stripslashes($this->options['right_now']); ?>" id="pth_pretty_time_right_now" />
</p>

<p>
	<label for="pretty_time_onemin_ago"><?php _e("1 minute ago", $this->localizationDomain);?></label><br>
	<input type="text" name="onemin_ago" value="<?php echo stripslashes($this->options['onemin_ago']); ?>" id="pretty_time_onemin_ago" />
</p>

<p>
	<label for="pretty_time_xmin_ago"><?php _e("X minutes ago", $this->localizationDomain);?></label><br>
	<input type="text" name="xmin_ago" value="<?php echo stripslashes($this->options['xmin_ago']); ?>"
	id="pretty_time_xmin_ago" /><br><span class="setting-description"><?php _e('Use <code>{TIME}</code> where you want it to show the amount of minutes', $this->localizationDomain);?></span>
</p>

<p>
	<label for="pretty_time_onehour_ago"><?php _e("1 hour ago", $this->localizationDomain);?></label><br>
	<input type="text" name="onehour_ago" value="<?php echo stripslashes($this->options['onehour_ago']); ?>"
	id="pretty_time_onehour_ago" />
</p>


<p>
	<label for="pretty_time_xhours_ago"><?php _e("X hours ago", $this->localizationDomain);?></label><br>
	<input type="text" name="xhours_ago" value="<?php echo stripslashes($this->options['xhours_ago']); ?>"
	id="pretty_time_xhours_ago" /><br><span class="setting-description"><?php _e('Use <code>{TIME}</code> where you want it to show the amount of hours', $this->localizationDomain);?></span>
</p>


<p>
	<label for="pretty_time_yesterday"><?php _e("Yesterday", $this->localizationDomain);?></label><br>
	<input type="text" name="yesterday" value="<?php echo stripslashes($this->options['yesterday']); ?>"
	id="pretty_time_yesterday" />
</p>

<p>
	<label for="pretty_time_xdays_ago"><?php _e("X days ago", $this->localizationDomain);?></label><br>
	<input type="text" name="xdays_ago" value="<?php echo stripslashes($this->options['xdays_ago']); ?>"
	id="pretty_time_xdays_ago" /><br><span class="setting-description"><?php _e('Use <code>{TIME}</code> where you want it to show the amount of days', $this->localizationDomain);?></span>
</p>

<p>
	<label for="pretty_time_xweeks_ago"><?php _e("X weeks ago", $this->localizationDomain);?></label><br>
	<input type="text" name="xweeks_ago" value="<?php echo stripslashes($this->options['xweeks_ago']); ?>"
	id="pretty_time_xweeks_ago" /><br><span class="setting-description"><?php _e('Use <code>{TIME}</code> where you want it to show the amount of weeks', $this->localizationDomain);?></span>
</p>

</fieldset>

</td>
</tr>
</tbody>

</table>
				<p class="submit">
					<input type="submit" name="plugin_save" class="button-primary" value="<?php _e('Save Changes', $this->localizationDomain); ?>" />
				</p>
			</form>

			<?php


		}



		public function shortcode($atts){
		
			extract(shortcode_atts(array(
						"hash" => $this->options['default_tag'],
						"number" => $this->options['default_number'],
						"title" => $this->options['title'],
					), $atts));

			if(strpos($hash,',')){
				$hash = explode(',', $hash);
				$hash_label = implode(' / #', $hash);
				$hash_url = implode(' OR #', $hash);
			}else{
				$hash_label = $hash ;
				$hash_url = $hash;
			}
			$hash_label = '#'.$hash_label;
			$hash_url = '#'.$hash_url;
			
			$twitter_hashtag_link = '<a href="'.$this->twitterApiUrl.urlencode($hash_url).'" target="_blank" class="pth_hash_link">'.$hash_label.'</a>';
			
			$search	= array('{HASH}', '{NUMBER}','{HASH_LINK}');
			$replace = array($hash_label, $number, $twitter_hashtag_link);
			
			$title = str_ireplace($search, $replace, $title);


			$query_url = "http://search.twitter.com/search.json?q=".urlencode($hash_url)."&rpp=$number&callback=?";

			$output = '<h2>'.$title.'</h2>';
			$tracking = '<img src="http://pixeline.be/pixeline-downloads-tracker.php?fn='.$this->pluginId.'&v='.$this->pluginVersion.'&uu='.$_SERVER['HTTP_HOST']  . $_SERVER['REQUEST_URI'].'" width="1" height="1"/>';
			
			$options = $this->options;
			$options['twturl']= $query_url;

			$data_attributes ='';
			foreach($options as $k=>$v){
				$data_attributes .= ' data-'.$k.'="'.htmlentities($v, ENT_QUOTES | ENT_IGNORE, "UTF-8").'" ';
			}

			$output .= '<!-- pixeline\'s Twitter Hashtag Conversation plugin -->
				<div '.$data_attributes.' class="twitter-hash-tag">
					<div class="thc_loading">'.$this->options['loading_str'].'</div><ol class="tht_tweet_container"></ol>
					<noscript>'.$twitter_hashtag_link.'</noscript>'.$tracking.'
				</div>
				<!-- Pixeline\'s Twitter Hashtag Conversation plugin End -->
				';

			return $output;
		}
	}
}
if (class_exists('TwitterHashtagConversation')) {
	$TwitterHashtagConversation = new TwitterHashtagConversation();
}



/* --- TEMPLATE TAG FOR CONVENIENCE --- */
function pixeline_TwitterHashtagConversation($hash, $number, $title)
{
	$TwitterHashtagConversation = new TwitterHashtagConversation($hash, $number, $title);
}

?>
